<?php

namespace ManiaLivePlugins\Flo\Admin\Gui\Windows;

use ManiaLib\Gui\Layouts\Column;
use ManiaLive\Gui\Windowing\Controls\Frame;
use ManiaLive\Data\Storage;
use ManiaLive\DedicatedApi\Connection;
use ManiaLive\Gui\Windowing\Controls\ButtonResizeable;
use ManiaLive\Gui\Windowing\Controls\Panel;
use ManiaLive\Gui\Windowing\Windows\Dialog;
use ManiaLive\Gui\Windowing\Windows\Info;
use ManiaLive\Gui\Windowing\Window;

class ChooseMode extends \ManiaLive\Gui\Windowing\Window
{
	protected $panel;
	protected $btn_container;
	protected $modes;
	protected $dialog;
	
	function initializeComponents()
	{
		// define game modes ...
		$this->modes = array
		(
			'Rounds',
			'Time Attack',
			'Team',
			'Laps',
			'Stunts',
			'Cup'
		);
		
		$this->setSize(50, 32);
		
		// create panel with close button ...
		$this->panel = new Panel();
		$this->panel->setTitle('Choose Mode');
		$this->addComponent($this->panel);
		
		// create layout for buttons ...
		$this->btn_container = new Frame();
		$this->btn_container->applyLayout(new Column());
		$this->addComponent($this->btn_container);
		
		// create button for each game mode ...
		foreach ($this->modes as $i => $mode)
		{
			$ui = new ButtonResizeable(15, 4);
			$ui->setHalign('center');
			$ui->setText($mode);
			$ui->setAction($this->callback('onClickMode', $i));
			$this->btn_container->addComponent($ui);
		}
	}
	
	function onShow()
	{
		// stretch panel onto full window size ...
		$this->panel->setSize($this->getSizeX(), $this->getSizeY());
		
		// resize buttons and assign actions ...
		$components = $this->btn_container->getComponents();
		foreach ($components as $i => $component)
		{
			$mode = $this->modes[$i];
			if (Storage::getInstance()->gameInfos->gameMode == $i)
				$component->setText($mode.' (current)');
			else
				$component->setText($mode);
			$component->setSizeX($this->getSizeX() - 4);
		}
		
		// move buttons to right position ....
		$this->btn_container->setPosition($this->getSizeX() / 2, 6);
	}
	
	function dialogClosed(Window $dialog)
	{
		if ($dialog == $this->dialog)
		{
			if ($dialog->getAnswer() == Dialog::YES)
			{
				Connection::getInstance()->restartChallenge();
				$this->hide();
			}
		}
	}
	
	function onClickMode($login, $mode)
	{
		try
		{
			Connection::getInstance()->setGameMode($mode);
			$dialog = Dialog::Create($login);
			$dialog->setSize(40, 20);
			$dialog->setTitle('Game Mode Changed!');
			$message = 'You have selected '.$this->modes[$mode].",\n";
			$message .= "New game mode will be set on map change!\n";
			$message .= "Do you want to restart now?";
			$dialog->setText($message);
			$dialog->setButtons(Dialog::YES | Dialog::NO);
			$this->showDialog($dialog);
			$this->dialog = $dialog;
		}
		catch (\Exception $ex)
		{
			$win = Info::Create($login);
			$win->setSize(40, 20);
			$win->setTitle('Error');
			$win->setText($ex->getMessage());
			$this->showDialog($win);
		}
	}
}

?>